==> process-kafka-quickstart-springboot-1.5.0.Final-sources.jar: defaultPackage/RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0.java <==
package defaultPackage;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.acme.travel.Traveller;
import static defaultPackage.RulesE5717FD31E01E6A14765D39787C99F47.*;

public class RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0 {

    /**
     * Rule name: Process travellers
     */
    public static org.drools.model.Rule rule_Process_32travellers() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Process travellers").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                            "travellers")
                                                                 .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                       defaultPackage.P2F.LambdaPredicate2F71BC7DF611CDF36409C405BECB973C.INSTANCE,
                                                                                                       D.alphaIndexedBy(boolean.class,
                                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                        DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                        defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                        false),
                                                                                                       D.reactOn("processed")).expr("7A4D786786CA592335131B19292DCAA2",
                                                                                                                                    defaultPackage.PED.LambdaPredicateED16CBB127736677B6F80086BB66A931.INSTANCE,
                                                                                                                                    D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                     org.drools.model.Index.ConstraintType.NOT_EQUAL,
                                                                                                                                                     DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                     defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                     "American"),
                                                                                                                                    D.reactOn("nationality")),
                                                                        D.on(var_$traveller).execute(defaultPackage.PA5.LambdaConsequenceA5A36002EBFB0332B66CB8F03C337FB4.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Don't process travellers from US
     */
    public static org.drools.model.Rule rule_Don_39t_32process_32travellers_32from_32US() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Don't process travellers from US").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                                          "travellers")
                                                                               .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                                     defaultPackage.P2F.LambdaPredicate2F71BC7DF611CDF36409C405BECB973C.INSTANCE,
                                                                                                                     D.alphaIndexedBy(boolean.class,
                                                                                                                                      org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                      DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                                      defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                                      false),
                                                                                                                     D.reactOn("processed")).expr("68191149A3CDE5A95B4E42CAFC6EA789",
                                                                                                                                                  defaultPackage.PC4.LambdaPredicateC4B42298D74DF0A1C977B27E41A78F95.INSTANCE,
                                                                                                                                                  D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                                   org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                                                   DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                                   defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                                   "American"),
                                                                                                                                                  D.reactOn("nationality")),
                                                                                      D.on(var_$traveller).execute(defaultPackage.PDE.LambdaConsequenceDE16905015D6A6C568A5CE1303BC02DF.INSTANCE));
        return rule;
    }
}

==> process-kafka-quickstart-springboot-1.6.0.Final-sources.jar: defaultPackage/RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0.java <==
package defaultPackage;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.acme.travel.Traveller;
import static defaultPackage.RulesE5717FD31E01E6A14765D39787C99F47.*;

public class RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0 {

    /**
     * Rule name: Process travellers
     */
    public static org.drools.model.Rule rule_Process_32travellers() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Process travellers").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                            "travellers")
                                                                 .build(D.pattern(var_$traveller).expr("GENERATED_1431ED0539270BF7254590AD8439205F",
                                                                                                       defaultPackage.P37.LambdaPredicate37916402ACBD691F46F86AEDBC8CC24F.INSTANCE,
                                                                                                       D.alphaIndexedBy(boolean.class,
                                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                        DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                        defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                        false),
                                                                                                       D.reactOn("processed")).expr("GENERATED_7A4D786786CA592335131B19292DCAA2",
                                                                                                                                    defaultPackage.P85.LambdaPredicate859415FC9E55141F7C213223C057E459.INSTANCE,
                                                                                                                                    D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                     org.drools.model.Index.ConstraintType.NOT_EQUAL,
                                                                                                                                                     DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                     defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                     "American"),
                                                                                                                                    D.reactOn("nationality")),
                                                                        D.on(var_$traveller).execute(defaultPackage.PDB.LambdaConsequenceDB15E1BAB4340CF37CDDB3E94958C4C7.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Don't process travellers from US
     */
    public static org.drools.model.Rule rule_Don_39t_32process_32travellers_32from_32US() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Don't process travellers from US").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                                          "travellers")
                                                                               .build(D.pattern(var_$traveller).expr("GENERATED_1431ED0539270BF7254590AD8439205F",
                                                                                                                     defaultPackage.P37.LambdaPredicate37916402ACBD691F46F86AEDBC8CC24F.INSTANCE,
                                                                                                                     D.alphaIndexedBy(boolean.class,
                                                                                                                                      org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                      DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                                      defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                                      false),
                                                                                                                     D.reactOn("processed")).expr("GENERATED_68191149A3CDE5A95B4E42CAFC6EA789",
                                                                                                                                                  defaultPackage.PCF.LambdaPredicateCF1D56025ACD7F965035FC4DD94C3BB7.INSTANCE,
                                                                                                                                                  D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                                   org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                                                   DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                                   defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                                   "American"),
                                                                                                                                                  D.reactOn("nationality")),
                                                                                      D.on(var_$traveller).execute(defaultPackage.PB3.LambdaConsequenceB3D22D4EF8725C47598CE06CE4DF27F0.INSTANCE));
        return rule;
    }
}
